@@ -47,6 +47,44 @@ def get_channel(e):
 
 	return int((e-1.6)/0.04)
 
+def create_user_gti(time, in_rate, in_drate, lognormal=True, gti_name='user_gtis.fits', 
+                    level_down=100, level_up = 0, quantile=0.8, make_plot=True, 
+                    far=1e-4):
+	import numpy as np
+	from stingray.gti import create_gti_from_condition
+	from astropy.io import fits as pf
+	from . import utils
+
+	if lognormal:
+		rate = np.log10(in_rate)
+		drate = in_drate/in_rate
+	else:
+		rate = in_rate
+		drate = in_drate
+        
+	limit_down, limit_up = utils.rate_filter(time, rate, drate, 
+                                       level_down=level_down, 
+                                       level_up = level_up, 
+                                       quantile=quantile, 
+                                       make_plot=make_plot, 
+                                       far=far)
+    
+	new_gti = create_gti_from_condition(time, (rate > limit_down) & (rate < limit_up) )
+
+	if len(new_gti.shape)>1:
+		start=new_gti[:,0]
+		stop=new_gti[:,1]
+		c1 = pf.Column(name='START', format='D', unit='s', array=start)
+		c2 = pf.Column(name='STOP', format='D', unit='s', array=stop)
+		coldefs = pf.ColDefs([c1, c2])
+		tbhdu = pf.BinTableHDU.from_columns(coldefs)
+		tbhdu.header['EXTNAME']='GTI'
+		tbhdu.writeto(gti_name, overwrite=True)
+	else:
+		logger.warning('No GTI file written, as no GTIs are present')
+    
+	return new_gti.shape[0]
+
 def prepare_outdir(outdir):
 
 	'''
