@@ -1098,6 +1098,53 @@ def get_fourier_coeff_error( counts, counts_err, n_simul=100, use_poisson=False)
 
     return np.std(sim_phi0), np.std(sim_phi0_2,), np.std(sim_A), np.std(sim_A2)
 
+def rate_filter(time, rate, drate, level_down=100, level_up = 0, quantile=0.8, make_plot=True, 
+                far=1e-4):
+    help = '''
+sas_cr_filter(self, typical_level=0.5, quantile=0.7,  make_plot=True, far=1e-3,
+                    tmin=0,tmax=1e12):
+This function prepares cleaned events by apllying standard filters for PN and MOS 
+(technically ev_fileter_expressions , are inherited from the general class and specialized in the derived classe) 
+cleans for CR flares if apply_rate_filter=True
+It is possible to select a time filter by setting tmin and tmax. This is useful if one want to eliminate a noise part
+of observation.
+The filter is controlled in the following way:
+- a light curve is extracted in time bins of 100 s above 10 keV
+- a Gaussian is fitted on LC data within the lower quantile (default=0.8) of the light curve
+- a limit is set on FAR, but it can be overrided by using the typical_level parameter, which is the lowest possible limit.
+        '''
+        
+    print(help)
+
+    if make_plot:
+        f, axes = plt.subplots(1, 2)
+        axes[0].errorbar(time, rate, yerr=drate, linestyle='none')
+        #axes[0].set_title(self.target + ' ' + self.obs_id)
+        axes[0].set_xlabel('Time [s]')
+        n_hist, edges, patches = axes[1].hist(rate, bins=300, density=True, facecolor='green',
+                                              alpha=0.75)
+    # x=(edges[0:-2]+edges[1:])/2
+    from scipy.stats import norm
+    ind = rate <= np.quantile(rate, quantile)
+    (mu, sigma) = norm.fit(rate[ind])
+
+    y = norm.pdf(edges, mu, sigma)
+
+    fap = np.min([1. / len(rate), far])
+    tmp = norm.isf(fap, loc=mu, scale=sigma)
+    limit_up = np.max([level_up, tmp ])
+    limit_down = np.min([level_down, 2*mu-tmp])
+
+    if make_plot:
+        _ = axes[1].plot(edges, y, 'r--', linewidth=2)
+        _ = axes[1].axvline(limit_up, 0, 1, color='cyan')
+        _ = axes[0].axhline(limit_up, 0, 1, color='cyan')
+        _ = axes[1].axvline(limit_down, 0, 1, color='blue')
+        _ = axes[0].axhline(limit_down, 0, 1, color='blue')
+        
+        plt.savefig('rate_select.pdf')
+    return limit_down, limit_up
+
 def write_orbit_file_from_gbm_page(url, file_name='orbit.dat',
                                    orbital_parameters = ['axsin', 'Eccentricity', 'periastron',
                                                          'T<sub>', 'Orbital Period', 'Period Deriv.']):
